@@ -29,10 +29,16 @@
 #' @param outrep_file `character` Full path of the file where results of the
 #'  processing are to be stored (created in `MODIStsp_process`)
 #' @param verbose `logical` If FALSE, suppress processing messages, Default: TRUE
+#' @param parallel `logical` If TRUE, the function is run using parallel
+#'  processing, to speed-up the computation for large rasters (with a maximum
+#'  of 8 cores).
+#'  The number of cores is automatically determined; specifying it is also 
+#'  possible (e.g. `parallel = 4`). In this case, more than 8 cores can be
+#'  specified. If FALSE (default), single core processing is used.
 #' @return The function is called for its side effects
 #' @rdname MODIStsp_process_bands
-#' @author Lorenzo Busetto, phD (2014-2017) \email{lbusett@@gmail.com}
-#' @author Luigi Ranghetti, phD (2015) \email{ranghetti.l@@irea.cnr.it}
+#' @author Lorenzo Busetto, phD (2014-2017)
+#' @author Luigi Ranghetti, phD (2015) \email{luigi@@ranghetti.info}
 #' @importFrom parallel detectCores
 #' @importFrom sf gdal_utils gdal_subdatasets sf_extSoftVersion
 #' @importFrom stats na.omit
@@ -50,7 +56,7 @@ MODIStsp_process_bands <- function(out_folder_mod, modislist,
                                    out_format, outrep_file, compress,
                                    out_res_sel, out_res, resampling,
                                    nodata_change,
-                                   gui, verbose) {
+                                   gui, verbose, parallel) {
 
   tmpdir <- file.path(tempdir(), "mstp_temp")
   dir.create(tmpdir, showWarnings = FALSE)
@@ -62,7 +68,13 @@ MODIStsp_process_bands <- function(out_folder_mod, modislist,
   #   number of available cpus > 8 (this to avoid overloading servers with high
   #   number of cpus)
 
-  ncores <- min(c(8, parallel::detectCores() - 2))
+  ncores <- if (is.numeric(parallel)) {
+    as.integer(parallel)
+  } else if (parallel == FALSE) {
+    1
+  } else {
+    min(c(8, parallel::detectCores() - 2))
+  }
 
   # check to see if the patch to correct wrong resolution/bbox in some HDF4 ----
   # original layers (e.g. albedo) is needed
@@ -316,7 +328,7 @@ MODIStsp_process_bands <- function(out_folder_mod, modislist,
                             outproj_str,
                             mod_proj_str,
                             enlarge = TRUE)
-    # Create a resized and (if needed) mosaiced GDAL vrt file
+    # Create a resized and (if needed) mosaicked GDAL vrt file
 
     if (datatype == "UInt32") {
       # fix to avoid bug on gdalbuildvrt for UInt32 datasets;
